/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package com.ebmwebsourcing.jbi.adaptor.impl;

import static org.mockito.Mockito.when;

import java.net.URI;

import javax.jbi.messaging.MessageExchange;
import javax.jbi.messaging.MessageExchange.Role;
import javax.jbi.servicedesc.ServiceEndpoint;
import javax.xml.namespace.QName;

import org.mockito.Mockito;
import org.ow2.petals.commons.log.FlowAttributes;
import org.ow2.petals.commons.log.FlowAttributesExchangeHelper;
import org.ow2.petals.component.api.ServiceConfiguration;
import org.ow2.petals.jbi.messaging.exchange.PetalsMessageExchange;
import org.ow2.petals.jbi.messaging.exchange.impl.MessageExchangeImpl;
import org.ow2.petals.jbi.servicedesc.endpoint.Location;

import com.ebmwebsourcing.easycommons.lang.UncheckedException;
import com.ebmwebsourcing.easycommons.uuid.SimpleUUIDGenerator;

/**
 * @author Marc Jambert - EBM WebSourcing
 */
public abstract class AbstractWrappedToComponentMessage extends AbstractWrappedMessage {

    private static final SimpleUUIDGenerator UUID_GENERATOR = new SimpleUUIDGenerator();

    public AbstractWrappedToComponentMessage(MessageExchange messageExchange) {
        super(messageExchange);
    }

    protected AbstractWrappedToComponentMessage(ServiceConfiguration serviceConfiguration,
            QName operation, URI mep, FlowAttributes flowAttributes) {
        super(createMessageExchange(serviceConfiguration.getEndpointName(),
                serviceConfiguration.getServiceQName(), serviceConfiguration.getInterfaceQName(),
                operation, mep, flowAttributes));
    }

    private static final MessageExchange createMessageExchange(String endpointName,
            QName serviceName, QName interfaceName, QName operation, URI mep,
            FlowAttributes flowAttributes) {
        ServiceEndpoint mockServiceEndpoint = Mockito.mock(ServiceEndpoint.class);
        when(mockServiceEndpoint.getEndpointName()).thenReturn(endpointName);
        when(mockServiceEndpoint.getServiceName()).thenReturn(serviceName);

        // TODO we should rely on the factory to build it...
        final MessageExchangeImpl messageExchange = new MessageExchangeImpl(UUID_GENERATOR.getNewID(), mep,
                new Location("test", "test"));
        messageExchange.setInterfaceName(interfaceName);
        messageExchange.setEndpoint(mockServiceEndpoint);
        messageExchange.setService(serviceName);
        messageExchange.setOperation(operation);
        FlowAttributesExchangeHelper.setFlowAttributes(messageExchange, flowAttributes);
        return messageExchange;
    }

    protected void setRole(Role role) {
        if (this.messageExchange instanceof PetalsMessageExchange) {
            ((PetalsMessageExchange) this.messageExchange).setRole(role);
        } else {
            throw new UncheckedException("The message exchange is not a PetalsMessageExchange: "
                    + this.messageExchange.getClass().getName());
        }
    }
}
