/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package com.ebmwebsourcing.jbi.adaptor.impl;

import static org.mockito.Mockito.when;

import java.io.InputStream;
import java.net.URI;

import javax.jbi.messaging.MessageExchange;
import javax.jbi.messaging.MessageExchange.Role;
import javax.jbi.messaging.MessagingException;
import javax.jbi.messaging.NormalizedMessage;
import javax.jbi.servicedesc.ServiceEndpoint;
import javax.xml.namespace.QName;
import javax.xml.transform.stream.StreamSource;

import org.mockito.Mockito;
import org.ow2.petals.commons.log.FlowAttributes;
import org.ow2.petals.component.api.ServiceConfiguration;
import org.ow2.petals.component.framework.api.message.Exchange;

import com.ebmwebsourcing.easycommons.lang.UncheckedException;

/**
 * @author Marc Jambert - EBM WebSourcing
 */
public class WrappedRequestToProviderMessage extends AbstractWrappedToComponentMessage {

    public WrappedRequestToProviderMessage(ServiceConfiguration serviceConfiguration, QName operation,
            URI mep, InputStream inMessageContentStream, FlowAttributes flowAttributes) {
        super(serviceConfiguration, operation, mep, flowAttributes);

        try {
            setRole(Role.CONSUMER);
            NormalizedMessage inNm = this.messageExchange.createMessage();
            inNm.setContent(new StreamSource(inMessageContentStream));
            this.messageExchange.setMessage(inNm, Exchange.IN_MESSAGE_NAME);
            setRole(Role.PROVIDER);
        } catch (MessagingException e) {
            throw new UncheckedException("Impossible to create a message exchange", e);
        }
    }

    public WrappedRequestToProviderMessage(MessageExchange messageExchange) {
        super(messageExchange);

        ServiceEndpoint mockServiceEndpoint = Mockito.mock(ServiceEndpoint.class);
        ServiceEndpoint endpoint = messageExchange.getEndpoint();
        String endpointName = null;
        if (endpoint != null) {
            endpointName = endpoint.getEndpointName();
        }
        QName serviceName = messageExchange.getService();
        when(mockServiceEndpoint.getEndpointName()).thenReturn(endpointName);
        when(mockServiceEndpoint.getServiceName()).thenReturn(serviceName);
        messageExchange.setEndpoint(mockServiceEndpoint);

        setRole(Role.PROVIDER);
    }
    
	@Override
	public String getPayload() {
		return getPayload("in");
	}

    
}
