/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package com.ebmwebsourcing.jbi.adaptor.impl;

import static org.junit.Assert.assertTrue;

import javax.jbi.messaging.ExchangeStatus;

import org.junit.Test;
import org.ow2.petals.commons.log.Level;
import org.ow2.petals.component.api.AbstractComponentTest;
import org.ow2.petals.component.api.Message;
import org.ow2.petals.component.api.ServiceConfiguration;

/**
 * @author Marc Jambert - EBM WebSourcing
 */
public abstract class AbstractJBIComponentTest extends AbstractComponentTest {
    
    protected abstract Message createTestStatusMessage(
            ServiceConfiguration testServiceConfiguration, ExchangeStatus status) throws Exception;
    
    @Test
    public void testNoMonitTraceOnDoneStatusAsProvider() throws Exception {
        testNoMonitTraceOnNonActiveStatusAsProvider(ExchangeStatus.DONE);
    }

    @Test
    public void testNoMonitTraceOnErrorStatusAsProvider() throws Exception {
        testNoMonitTraceOnNonActiveStatusAsProvider(ExchangeStatus.ERROR);
    }

    private void testNoMonitTraceOnNonActiveStatusAsProvider(ExchangeStatus status)
            throws Exception {
        ServiceConfiguration serviceConfiguration = createTestProvideServiceConfiguration();
        this.logger.setLevel(Level.MONIT);
        
        this.componentUnderTest.start();
        this.componentUnderTest.installService(serviceConfiguration);
                
        Message message = createTestStatusMessage(serviceConfiguration, status);
        ((WrappedComponent) this.componentUnderTest).processMessageFromServiceBus(message);
        
        assertTrue(this.testHandler.getAllRecords(Level.MONIT).size() == 0);
    }

}
