/**
 * Copyright (c) 2011-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package com.ebmwebsourcing.jbi.adaptor.impl;

import static org.junit.Assert.assertTrue;

import java.io.File;
import java.net.URL;
import java.util.logging.Logger;

import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.TemporaryFolder;
import org.ow2.petals.component.api.ComponentConfiguration;

import com.ebmwebsourcing.easycommons.io.IOHelper;
import com.ebmwebsourcing.easycommons.lang.UncheckedException;
import com.ebmwebsourcing.easycommons.xml.XMLComparator;

/**
 * @author Marc Jambert - EBM WebSourcing
 */
public class ComponentJbiGeneratorTest {

    @Rule
    public final TemporaryFolder tempFolder = new TemporaryFolder();

    @Test
    public void testGenerateFromEmptyComponentConfiguration() throws Exception {
        URL defaultJbiUrl = Thread.currentThread().getContextClassLoader()
                .getResource("jbi/jbi.xml");
        File tempInstallationRoot = this.tempFolder.newFolder("installationRoot");

        ComponentConfiguration componentConfiguration = new ComponentConfiguration("componentName", Logger.getAnonymousLogger());
        ComponentJbiGenerator componentJbiGenerator = new ComponentJbiGenerator(ComponentType.BC_FILETRANSFER,
                componentConfiguration, tempInstallationRoot);
        
        File defaultJbi = new File(defaultJbiUrl.toURI());
        assertTrue(defaultJbi.isAbsolute());
        String defaultJbiContent = IOHelper.readFileAsString(defaultJbi);
        
        File generatedComponentJbi = componentJbiGenerator.generate();
        String generatedComponentJbiContent = IOHelper.readFileAsString(generatedComponentJbi);
        
        // everything must be the same thant default jbi template, but the component name!
        assertTrue(XMLComparator.isEquivalent(
        		defaultJbiContent.replaceAll("<jbi:name>petals-bc-filetransfer</jbi:name>", 
        				"<jbi:name>componentName</jbi:name>"), 
        		generatedComponentJbiContent));
    }

    @Test(expected = UncheckedException.class)
    public void testGenerateButNoDefaultJbiXmlFoundInClasspath() throws Exception {
        File tempInstallationRoot = this.tempFolder.newFolder("installationRoot");

        ComponentConfiguration componentConfiguration = new ComponentConfiguration("componentName", Logger.getAnonymousLogger());
        new ComponentJbiGenerator(ComponentType.BC_FTP,
                componentConfiguration, tempInstallationRoot);
    }
    
    
}
